@@ -55,6 +55,8 @@ class Asset:
 
     effective_start_dt: datetime.datetime
     effective_end_dt: datetime.datetime
+    valid_start_dt: datetime.datetime = None
+    valid_end_dt: datetime.datetime = None
     knowledge_start_dt: datetime.datetime = None
     knowledge_end_dt: datetime.datetime = None
 
@@ -70,6 +72,12 @@ class Asset:
                 parts.add(str(to_timestamp(self.effective_start_dt)))
             elif k == "effective_end_dt":
                 parts.add(str(to_timestamp(self.effective_end_dt)))
+            elif k == "valid_start_dt":
+                if self.valid_start_dt:
+                    parts.add(str(to_timestamp(self.valid_start_dt)))
+            elif k == "valid_end_dt":
+                if self.valid_end_dt:
+                    parts.add(str(to_timestamp(self.valid_end_dt)))
             elif k == "knowledge_start_dt":
                 if self.knowledge_start_dt:
                     parts.add(str(to_timestamp(self.knowledge_start_dt)))
@@ -106,6 +114,14 @@ class Asset:
             self.effective_end_dt.strftime("%Y-%m-%d") + " 00:00:00.00000"
         )
 
+        if self.valid_start_dt is None:
+            self.valid_start_dt = (
+                self.effective_end_dt.strftime("%Y-%m-%d") + " 00:00:00.00000"
+            )
+
+        if self.valid_end_dt is None:
+            self.valid_end_dt = datetime.datetime(year=3000, month=12, day=31)
+
         if self.knowledge_start_dt is None:
             self.knowledge_start_dt = datetime.datetime.utcnow()
 
@@ -114,6 +130,13 @@ class Asset:
                 year=3000, month=12, day=31
             )
 
+        parts.append(
+            self.valid_start_dt.strftime("%Y-%m-%d") + " 00:00:00.00000"
+        )
+        parts.append(
+            self.valid_end_dt.strftime("%Y-%m-%d") + " 00:00:00.00000"
+        )
+
         parts.append(
             self.knowledge_start_dt.strftime("%Y-%m-%d") + " 00:00:00.00000"
         )
@@ -160,6 +183,8 @@ class Descriptor:
     value: str
     effective_start_dt: datetime.datetime
     effective_end_dt: datetime.datetime
+    valid_start_dt: datetime.datetime = None
+    valid_end_dt: datetime.datetime = None
     knowledge_start_dt: datetime.datetime = None
     knowledge_end_dt: datetime.datetime = None
 
